@@ -3,12 +3,12 @@ package Number::Phone::JP::Table::Pager;
 use strict;
 use warnings;
 
-our $VERSION = '0.20170601';
+our $VERSION = '0.20170703';
 
-# Table last modified: 2017-06-01
+# Table last modified: 2017-07-03
 our %TEL_TABLE = (
     # Pref => q<Assoc-Pref-Regex>,
-    20 => '(?:4(?:9[29]|6\d)\d{5})',
+    20 => '(?:46\d{6})',
 );
 
 1;
